"""
TEST:

stylerule2 = css.CSSStyleRule()
stylerule2.cssText = 'a {color: red;left: 1px }'

stylerule3 = css.CSSStyleRule()
stylerule3.cssText = 'a { }'
"""

__version__ = '0.8a3'


import unittest
import xml.dom

import cssutils.css

import test_cssrule


class CSSStyleRuleTestCase(test_cssrule.CSSRuleTestCase):

    def setUp(self):
        self.r = cssutils.css.CSSStyleRule()
        self.rRO = cssutils.css.CSSStyleRule(readonly=True)
        self.r_type = cssutils.css.CSSStyleRule.STYLE_RULE

        self.d = cssutils.css.CSSStyleDeclaration()


    def test_selectors(self):
        self.assertEqual(0, len(self.r.getSelectors()))
        self.r.addSelector(u'a')
        self.assertEqual(1, len(self.r.getSelectors()))     
        self.assertEqual(u'a', self.r.selectorText)
        self.r.addSelector(u' b  , h1 ')
        self.assertEqual(3, len(self.r.getSelectors()))
        self.assertEqual(u'a, b, h1', self.r.selectorText)
        # comments


    def test_style(self):
        self.r.setStyleDeclaration(self.d)
        self.assertEqual(self.d, self.r.getStyleDeclaration())
        self.r.style = self.d


    def test_getCssText(self):
        self.r.addSelector(' b  , h1 ')
        self.r.setStyleDeclaration(self.d)
        self.assertEqual(u'b, h1 {\n\n}', self.r.getFormatted(0,0))    
        self.assertEqual(u'b, h1 {\n\n    }', self.r.cssText)    


    def test_selectors(self):
        self.r.cssText = u'*  {}'
        self.assertEqual(u'* {\n\n    }', self.r.cssText)
        self.r.cssText = u'#a  {}'
        self.assertEqual(u'#a {\n\n    }', self.r.cssText)
        self.r.cssText = u'e#a  {}'
        self.assertEqual(u'e#a {\n\n    }', self.r.cssText)
        self.r.cssText = u'.a  {}'
        self.assertEqual(u'.a {\n\n    }', self.r.cssText)
        self.r.cssText = u'e.a  {}'
        self.assertEqual(u'e.a {\n\n    }', self.r.cssText)

        self.r.cssText = u'a:hover {}'
        self.assertEqual(u'a:hover {\n\n    }', self.r.cssText)

        self.r.cssText = u'a b  {}'
        self.assertEqual(u'a b {\n\n    }', self.r.cssText)
        self.r.cssText = u'a *  {}'
        self.assertEqual(u'a * {\n\n    }', self.r.cssText)
        self.r.cssText = u'a>b  {}'
        self.assertEqual(u'a>b {\n\n    }', self.r.cssText)
        self.r.cssText = u'a+b  {}'
        self.assertEqual(u'a+b {\n\n    }', self.r.cssText)
        self.r.cssText = u'a[x] {}'
        self.assertEqual(u'a[x] {\n\n    }', self.r.cssText)
        self.r.cssText = u'a[x=1] {}'
        self.assertEqual(u'a[x=1] {\n\n    }', self.r.cssText)
        self.r.cssText = u'a[x~=y] {}'
        self.assertEqual(u'a[x~=y] {\n\n    }', self.r.cssText)
        self.r.cssText = u'a[x|=y] {}'
        self.assertEqual(u'a[x|=y] {\n\n    }', self.r.cssText)

        self.r.cssText = u':lang(de) {}'
        self.assertEqual(u':lang(de) {\n\n    }', self.r.cssText)
        self.r.cssText = u'a:lang(de) {}'
        self.assertEqual(u'a:lang(de) {\n\n    }', self.r.cssText)


    def test_setCssText(self):
        self.r.cssText = u'a  { color     :  red   ; }'
        self.assertEqual(u'a {\n    color: red;\n    }', self.r.cssText)

        self.r.cssText = u'a  , x:hover  {color     :  red   ;left:1px}'
        self.assertEqual(
            u'a, x:hover {\n    color: red;\n    left: 1px;\n    }',
            self.r.cssText)

        self.assertRaises(xml.dom.SyntaxErr,
                          self.r._setCssText, u'a { color }')

        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, u'{ color }')

        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, u'@import url(x);')
        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, u'@charset "ascii";')
        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, u'@media all {}')
        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, u'@    ;')

        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, u'  @import url(x);')
        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, u'/*x*/ @import url(x);')
        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, u' /*x*/ @import url(x);')
        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, u'/*x*/ /*y*/ @import url(x);')
        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, u' /*x*/ /*y*/ @import url(x);')


if __name__ == '__main__':
    unittest.main() 