__version__ = '0.8a3'

import unittest
import xml.dom

import cssutils.css
import cssutils.stylesheets

import test_cssrule


class CSSUnknownRuleTestCase(test_cssrule.CSSRuleTestCase):


    def setUp(self):
        self.r = cssutils.css.CSSUnknownRule()
        self.rRO = cssutils.css.CSSUnknownRule(readonly=True)
        self.r_type = cssutils.css.CSSUnknownRule.UNKNOWN_RULE


    def test_init(self):
        super(CSSUnknownRuleTestCase, self).test_init()

        # only name
        r = cssutils.css.CSSUnknownRule(cssText=u'@init;')
        self.assertEqual(u'@init;', r.cssText)

        r = cssutils.css.CSSUnknownRule(cssText=u'@_w-h-a-012;')
        self.assertEqual(u'@_w-h-a-012;', r.cssText)

        # name and content
        r = cssutils.css.CSSUnknownRule(cssText=u'@init xxx;')
        self.assertEqual(u'@init xxx;', r.cssText)

        # name and block
        r = cssutils.css.CSSUnknownRule(cssText=u'@init { xxx }')
        self.assertEqual(u'@init { xxx }', r.cssText)

        # name and content and block
        r = cssutils.css.CSSUnknownRule(cssText=u'@init xxx { yyy }')
        self.assertEqual(u'@init xxx { yyy }', r.cssText)


    def test_SyntaxErr(self):
        # at keyword
        self.assertRaises(xml.dom.SyntaxErr,
                          self.r._setCssText, '@-unknown;')
        self.assertRaises(xml.dom.SyntaxErr,
                          self.r._setCssText, '@;')
        # rule end
        self.assertRaises(xml.dom.SyntaxErr,
                          self.r._setCssText, '@x }  ')
        self.assertRaises(xml.dom.SyntaxErr,
                          self.r._setCssText, '@x }  ;')
        self.assertRaises(xml.dom.SyntaxErr,
                          self.r._setCssText, '@x {  ')
        self.assertRaises(xml.dom.SyntaxErr,
                          self.r._setCssText, '@x {  ;')
        self.assertRaises(xml.dom.SyntaxErr,
                          self.r._setCssText, '@x ')
            

    def test_InvalidModificationErr(self):
        "known at-rules or no at-rule at all"
        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, '@charset "utf-8";')
        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, '@import url(x);')
##        self.assertRaises(xml.dom.InvalidModificationErr,
##                          self.r._setCssText, '@media {}')
##        self.assertRaises(xml.dom.InvalidModificationErr,
##                          self.r._setCssText, '@page {}')
        self.assertRaises(xml.dom.InvalidModificationErr,
                          self.r._setCssText, 'other { color: red;}')


if __name__ == '__main__':
    unittest.main() 